==> python-frontend-2.8.0.6204-sources.jar: org/sonar/python/types/TypeShedPythonFile.java <==
/*
 * SonarQube Python Plugin
 * Copyright (C) 2011-2020 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.python.types;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UncheckedIOException;
import java.net.URI;
import java.nio.charset.StandardCharsets;
import java.util.stream.Collectors;
import org.sonar.api.utils.log.Logger;
import org.sonar.api.utils.log.Loggers;
import org.sonar.plugins.python.api.PythonFile;

public class TypeShedPythonFile implements PythonFile {

  private static final Logger LOG = Loggers.get(TypeShedPythonFile.class);

  private final InputStream resourceAsStream;

  TypeShedPythonFile(InputStream resourceAsStream) {
    this.resourceAsStream = resourceAsStream;
  }

  @Override
  public String content() {
    try (BufferedReader reader = new BufferedReader(new InputStreamReader(resourceAsStream, StandardCharsets.UTF_8))) {
      return reader.lines().collect(Collectors.joining("\n"));
    } catch (IOException | UncheckedIOException e) {
      LOG.info("Unable to read builtin types.", e);
      return "";
    }
  }

  @Override
  public String fileName() {
    return "";
  }

  @Override
  public URI uri() {
    return null;
  }
}

==> python-frontend-2.11.0.6843-sources.jar: org/sonar/python/types/TypeShedPythonFile.java <==
/*
 * SonarQube Python Plugin
 * Copyright (C) 2011-2020 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.python.types;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UncheckedIOException;
import java.net.URI;
import java.nio.charset.StandardCharsets;
import java.util.stream.Collectors;
import org.sonar.api.utils.log.Logger;
import org.sonar.api.utils.log.Loggers;
import org.sonar.plugins.python.api.PythonFile;

public class TypeShedPythonFile implements PythonFile {

  private static final Logger LOG = Loggers.get(TypeShedPythonFile.class);

  private final InputStream resourceAsStream;
  private final String filename;

  TypeShedPythonFile(InputStream resourceAsStream, String filename) {
    this.resourceAsStream = resourceAsStream;
    this.filename = filename;
  }

  @Override
  public String content() {
    try (BufferedReader reader = new BufferedReader(new InputStreamReader(resourceAsStream, StandardCharsets.UTF_8))) {
      return reader.lines().collect(Collectors.joining("\n"));
    } catch (IOException | UncheckedIOException e) {
      LOG.info("Unable to read builtin types.", e);
      return "";
    }
  }

  @Override
  public String fileName() {
    return filename;
  }

  @Override
  public URI uri() {
    return null;
  }
}
